@@ -42,11 +42,12 @@ from emannotationschemas.schemas.proofreading import (
 from emannotationschemas.schemas.neuropil import FlyNeuropil
 from emannotationschemas.schemas.groups import SimpleGroup
 from emannotationschemas.schemas.fly_cell_types import FlyCellType, FlyCellTypeExt
+from emannotationschemas.schemas.braincircuits import BrainCircuitsBoundTagAnnotationUser
 
 from emannotationschemas.errors import UnknownAnnotationTypeException
 from emannotationschemas.flatten import create_flattened_schema
 
-__version__ = "5.1.1"
+__version__ = "5.2.0"
 
 type_mapping = {
     "synapse": SynapseSchema,
@@ -85,6 +86,7 @@ type_mapping = {
     "reference_simple_group": SimpleGroup,
     "fly_cell_type": FlyCellType,
     "fly_cell_type_ext": FlyCellTypeExt,
+    "braincircuits_annotation_user": BrainCircuitsBoundTagAnnotationUser,
 }
 
 
